BjmobSdkPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • BjmobSdkPlatform
Implementers

Constructors

BjmobSdkPlatform()
Constructs a BjmobSdkPlatform.

Properties

adEventStream Stream<AdEvent>
广告事件流
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

destroy() Future<void>
getPlatformVersion() Future<String?>
initialize() Future<void>
loadBanner(String adContainer) Future<void>
loadDraw(String adContainer) Future<void>
loadFullScreenVideo() Future<void>
loadInterstitial() Future<void>
loadNativeExpress(String adContainer) Future<void>
loadRewardVideo() Future<void>
loadSplash({required String adContainer, String? logoContainer, bool singleActivity = true}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance BjmobSdkPlatform
The default instance of BjmobSdkPlatform to use.
getter/setter pair